__version__ = "0.1.0"
VERSION = __version__

from .pipeline.baseline import BaselineAnalyzersPipeline
from .features.address_feature_analyzer import AddressFeatureAnalyzer
from .patterns.structural_pattern_analyzer import StructuralPatternAnalyzer
from .adapters.parquet import ParquetAdapter
from .adapters.clickhouse import ClickHouseAdapter

__all__ = [
    "VERSION",
    "__version__",
    "BaselineAnalyzersPipeline",
    "AddressFeatureAnalyzer",
    "StructuralPatternAnalyzer",
    "ParquetAdapter",
    "ClickHouseAdapter",
]
